@@ -41,7 +41,8 @@ static QMap<QString, void (NetworkDialog::*)(QLocalSocket *, const QByteArray &)
     { "password", &NetworkDialog::sendPassword },
     { "connect", &NetworkDialog::connectNetwork },
     { "close", &NetworkDialog::closeServer },
-    { "start", &NetworkDialog::startServer }
+    { "start", &NetworkDialog::startServer },
+    { "grabKeyboard", &NetworkDialog::onGrabKeyboard }
 };
 
 /**
@@ -90,7 +91,8 @@ void NetworkDialog::show()
         m_process->blockSignals(true);
         m_process->close();
         m_process->blockSignals(false);
-        requestFocus();
+        if (Greeter == m_runReason)
+            requestFocus();
         runProcess(true);
     });
 }
@@ -126,9 +128,16 @@ bool NetworkDialog::eventFilter(QObject *watched, QEvent *e)
     if (qobject_cast<TrayIcon *>(watched)) {
         switch (e->type()) {
         case QEvent::Show:
+            // 在事件循环中处理,因为位置有可能没有及时更新
+            QTimer::singleShot(0, this, [this] {
+                for (auto it = m_clients.begin(); it != m_clients.end(); it++)
+                    forceShowDialog(it.key());
+            });
+            break;
         case QEvent::Hide:
-            for (auto it = m_clients.begin(); it != m_clients.end(); it++)
-                forceShowDialog(it.key());
+            // 网络插件隐藏的时候关闭弹窗
+            // 主要是为了规避锁屏和网络列表争抢键盘的问题（可能会导致锁屏失败，退出进程）
+            closeDialog();
             break;
         default:
             break;
@@ -146,6 +155,7 @@ bool NetworkDialog::eventFilter(QObject *watched, QEvent *e)
     if (watched == m_focusWidget && e->type() == QEvent::WindowDeactivate) {
         return true;
     }
+
     return QObject::eventFilter(watched, e);
 }
 
@@ -264,6 +274,7 @@ void NetworkDialog::readyReadHandler()
     if (socket) {
         QByteArray allData = socket->readAll();
         allData = m_lastData + allData;
+        qDebug() << "Recieve data from client: " << allData;
         QList<QByteArray> dataArray = allData.split('\n');
         m_lastData = dataArray.last();
         for (const QByteArray &data : dataArray) {
@@ -295,15 +306,25 @@ QByteArray NetworkDialog::showConfig()
 void NetworkDialog::showDialog(QLocalSocket *socket, const QByteArray &)
 {
     emit requestPosition();
-    requestFocus();
+    if (Greeter == m_runReason)
+        requestFocus();
     m_clients[socket] = ClientType::Show;
     socket->write("\nshowPosition:" + showConfig() + "\n");
 }
 
+void NetworkDialog::onGrabKeyboard(QLocalSocket *socket, const QByteArray &data)
+{
+    Q_UNUSED(socket)
+    Q_UNUSED(data)
+
+    requestFocus();
+}
+
 void NetworkDialog::forceShowDialog(QLocalSocket *socket)
 {
     emit requestPosition();
-    requestFocus();
+    if (Greeter == m_runReason)
+        requestFocus();
     m_clients[socket] = ClientType::Show;
 
     QJsonObject json;
@@ -319,6 +340,17 @@ void NetworkDialog::forceShowDialog(QLocalSocket *socket)
     socket->write("\nshowPosition:" + data + "\n");
 }
 
+void NetworkDialog::closeDialog()
+{
+    for (auto it = m_clients.begin(); it != m_clients.end(); it++)
+        closeDialog(it.key());
+}
+
+void NetworkDialog::closeDialog(QLocalSocket *socket)
+{
+    socket->write("\nclose:" + QByteArray() + "\n");
+}
+
 void NetworkDialog::connectNetwork(QLocalSocket *socket, const QByteArray &data)
 {
     QLocalSocket *showSocket = nullptr;
@@ -361,3 +393,9 @@ void NetworkDialog::startServer(QLocalSocket *socket, const QByteArray &data)
     QLocalServer::removeServer(m_serverName);
     m_server->listen(m_serverName);
 }
+
+void NetworkDialog::updateDialogPosition()
+{
+    for (auto it = m_clients.begin(); it != m_clients.end(); it++)
+        showDialog(it.key(), QByteArray());
+}
