@@ -58,6 +58,7 @@ public:
     void setPosition(int x, int y, Dtk::Widget::DArrowRectangle::ArrowDirection position = Dtk::Widget::DArrowRectangle::ArrowDirection::ArrowBottom);
     bool isVisible() const;
     void setLocale(const QString &locale);
+    void closeDialog();
 
 private:
     void runProcess(bool show = true);
@@ -82,7 +83,10 @@ public:
     void sendPassword(QLocalSocket *socket, const QByteArray &data);
     void closeServer(QLocalSocket *socket, const QByteArray &data);
     void startServer(QLocalSocket *socket, const QByteArray &data);
+    void onGrabKeyboard(QLocalSocket *socket, const QByteArray &data);
+    void closeDialog(QLocalSocket *socket);
     QByteArray showConfig();
+    void updateDialogPosition();
 
 private:
     int m_x;
