@@ -30,6 +30,7 @@
 #include <widgets/contentwidget.h>
 
 #include <networkmanagerqt/connection.h>
+#include <networkmanagerqt/activeconnection.h>
 #include <networkmanagerqt/connectionsettings.h>
 
 namespace dcc {
@@ -77,6 +78,7 @@ public:
     static void setFrameProxy(FrameProxyInterface *frame);
     void setButtonTupleEnable(bool enable);
     void setLeftButtonEnable(bool enable);
+    void initHeaderButtons();
 
 Q_SIGNALS:
     void requestNextPage(ContentWidget *const page);
@@ -100,13 +102,12 @@ protected:
 
 private:
     void initUI();
-    void initHeaderButtons();
     void initConnection();
     void initConnectionSecrets();
     void saveConnSettings();
     void updateConnection();
     void createConnSettings();
-    bool isConnected();
+    const NetworkManager::ActiveConnection::State ConnectedState();
 
     NMVariantMapMap secretsMapMapBySettingType(Setting::SettingType settingType);
     // T means a Setting subclass, like WirelessSecuritySetting
