@@ -33,6 +33,7 @@
 #include "wiredpage.h"
 #include "wirelesspage.h"
 #include "window/gsettingwatcher.h"
+#include "airplanemodepage.h"
 
 #include <QLayout>
 
@@ -44,10 +45,13 @@
 #include <hotspotcontroller.h>
 
 #include <NetworkManagerQt/Manager>
+#include <DConfig>
 
 using namespace dde::network;
 using namespace dccV20;
 using namespace dcc;
+using namespace DCC_NAMESPACE::network;
+DCORE_USE_NAMESPACE
 
 DCCNetworkModule::DCCNetworkModule()
     : QObject()
@@ -55,6 +59,7 @@ DCCNetworkModule::DCCNetworkModule()
     , m_indexWidget(nullptr)
     , m_connEditPage(nullptr)
     , m_airplaneMode(new DBusAirplaneMode("com.deepin.daemon.AirplaneMode", "/com/deepin/daemon/AirplaneMode", QDBusConnection::systemBus(), this))
+    , m_dconfig(DConfig::create("org.deepin.dde.network", "org.deepin.dde.network", QString(), this))
 {
     QTranslator *translator = new QTranslator(this);
     translator->load(QString("/usr/share/dcc-network-plugin/translations/dcc-network-plugin_%1.qm").arg(QLocale::system().name()));
@@ -121,11 +126,23 @@ void DCCNetworkModule::active()
     connect(m_indexWidget, &NetworkModuleWidget::destroyed, [ this ] {
         m_indexWidget = nullptr;
     });
+    connect(m_indexWidget, &NetworkModuleWidget::requestShowAirplanePage, this, &DCCNetworkModule::showAirplanePage);
 
     m_frameProxy->pushWidget(this, m_indexWidget);
     m_indexWidget->setVisible(true);
     initListConfig();
     m_indexWidget->showDefaultWidget();
+
+    if (supportAirplaneMode()) {
+        m_networkInter = new NetworkInter("com.deepin.daemon.Network", "/com/deepin/daemon/Network", QDBusConnection::sessionBus(), this);
+        connect(m_networkInter, &NetworkInter::WirelessAccessPointsChanged, this, &DCCNetworkModule::onWirelessAccessPointsOrAdapterChange);
+
+        m_bluetoothInter = new BluetoothInter("com.deepin.daemon.Bluetooth", "/com/deepin/daemon/Bluetooth", QDBusConnection::sessionBus(), this);
+        connect(m_bluetoothInter, &BluetoothInter::AdapterAdded, this, &DCCNetworkModule::onWirelessAccessPointsOrAdapterChange);
+        connect(m_bluetoothInter, &BluetoothInter::AdapterRemoved, this, &DCCNetworkModule::onWirelessAccessPointsOrAdapterChange);
+    } else {
+        onWirelessAccessPointsOrAdapterChange();
+    }
 }
 
 QStringList DCCNetworkModule::availPage() const
@@ -134,7 +151,7 @@ QStringList DCCNetworkModule::availPage() const
     list << "DSL" << "DSL/Create PPPoE Connection" << "VPN" << "VPN/Create VPN" << "VPN/Import VPN"
          << "System Proxy" << "Application Proxy" << "Network Details"
          << "Wired Network" << "Wired Network/addWiredConnection"
-         << "Wireless Network" << "WirelessPage" << "Personal Hotspot";
+         << "Wireless Network" << "WirelessPage" << "Personal Hotspot" << "Airplane Mode";
 
     QList<NetworkDeviceBase *> devices = NetworkController::instance()->devices();
     for (NetworkDeviceBase *dev: devices)
@@ -231,6 +248,9 @@ void DCCNetworkModule::initListConfig()
 
     auto setModulVisible = [ func_is_visible, this ](const QString &key, bool visible = true) {
         bool isVisible = func_is_visible(key) && visible;
+        if (key == "networkAirplane") {
+            isVisible = supportAirplaneMode();
+        }
         m_indexWidget->setModelVisible(key, isVisible);
     };
 
@@ -283,6 +303,56 @@ bool DCCNetworkModule::hasModule(const PageType &type)
     return true;
 }
 
+bool DCCNetworkModule::supportAirplaneMode() const
+{
+    // dde-dconfig配置优先级高于设备优先级
+    bool bAirplane = false;
+    if (m_dconfig && m_dconfig->isValid()) {
+        bAirplane = m_dconfig->value("networkAirplaneMode", false).toBool();
+    }
+    if (!bAirplane) {
+        return bAirplane;
+    }
+
+    // 蓝牙和无线网络,只要有其中一个就允许显示飞行模式
+    QDBusInterface inter("com.deepin.system.Bluetooth",
+                    "/com/deepin/system/Bluetooth",
+                    "com.deepin.system.Bluetooth",
+                    QDBusConnection::systemBus());
+    if (inter.isValid()) {
+        QDBusReply<QString> reply = inter.call("GetAdapters");
+        QString replyStr = reply.value();
+        QJsonDocument json = QJsonDocument::fromJson(replyStr.toUtf8());
+        QJsonArray array = json.array();
+        if (array.size() > 0 && !array[0].toObject()["Path"].toString().isEmpty()) {
+            return true;
+        }
+    }
+
+    QDBusInterface networkInter("org.freedesktop.NetworkManager",
+                                "/org/freedesktop/NetworkManager",
+                                "org.freedesktop.NetworkManager",
+                                QDBusConnection::systemBus());
+    if (networkInter.isValid()) {
+        QDBusReply<QList<QDBusObjectPath>> reply = networkInter.call("GetAllDevices");
+        QList<QDBusObjectPath> replyStrList = reply.value();
+        for (QDBusObjectPath objPath : replyStrList) {
+            QDBusInterface deviceInter("org.freedesktop.NetworkManager",
+                                        objPath.path(),
+                                        "org.freedesktop.NetworkManager.Device",
+                                        QDBusConnection::systemBus());
+            if (deviceInter.isValid()) {
+                QVariant reply = deviceInter.property("DeviceType");
+                if (2 == reply.toUInt()) {
+                    return true;
+                }
+            }
+        }
+    }
+
+    return false;
+}
+
 void DCCNetworkModule::initSearchData()
 {
     if (!m_frameProxy)
@@ -296,6 +366,7 @@ void DCCNetworkModule::initSearchData()
     const QString& wiredNetwork = tr("Wired Network");
     const QString& wirelessNetwork = tr("Wireless Network");
     const QString& vpn = tr("VPN");
+    const QString& airplaneMode = tr("Airplane Mode");
     const bool wiredVisible = hasModule(PageType::WiredPage);
     const bool wirelessVisible = hasModule(PageType::WirelessPage);
     const bool hotspotsVisible = hasModule(PageType::HotspotPage);
@@ -378,6 +449,26 @@ void DCCNetworkModule::initSearchData()
         m_frameProxy->setDetailVisible(module, vpn, tr("Import VPN"), bVPN);
     };
 
+    auto func_airplane_visible = [ = ] {
+        bool bAirplane = supportAirplaneMode();
+        if (m_indexWidget) {
+            m_indexWidget->setModelVisible("networkAirplane", bAirplane);
+        }
+        m_frameProxy->setWidgetVisible(module, airplaneMode, bAirplane);
+        //~ contents_path /network/Airplane Mode
+        //~ child_page Airplane Mode
+        m_frameProxy->setDetailVisible(module, airplaneMode, tr("Airplane Mode"), bAirplane);
+        if (!bAirplane) {
+            emit popAirplaneModePage();
+        }
+    };
+    if (m_dconfig && m_dconfig->isValid()) {
+        connect(m_dconfig, &DConfig::valueChanged, this, [ = ](const QString& key) {
+            if (key == "networkAirplaneMode") {
+                func_airplane_visible();
+            }
+        });
+    }
     auto func_sysproxy_visible = [ = ] {
         bool bSystemProxy = func_is_visible("systemProxy");
         if (m_indexWidget)
@@ -474,6 +565,7 @@ void DCCNetworkModule::initSearchData()
         func_wired_visible(wiredVisible);
         func_wireless_visible(wirelessVisible);
         func_perhotspot_visible(hotspotsVisible);
+        func_airplane_visible();
      };
 
     connect(this, &DCCNetworkModule::deviceChanged, this, [ = ] {
@@ -527,6 +619,7 @@ void DCCNetworkModule::addChildPageTrans() const
         m_frameProxy->addChildPageTrans("Application Proxy", tr("Application Proxy"));
         m_frameProxy->addChildPageTrans("Personal Hotspot", tr("Personal Hotspot"));
         m_frameProxy->addChildPageTrans("Network Details", tr("Network Details"));
+        m_frameProxy->addChildPageTrans("Airplane Mode", tr("Airplane Mode"));
     }
 }
 
@@ -677,3 +770,26 @@ void DCCNetworkModule::showDetailPage()
     m_frameProxy->pushWidget(this, detailPage);
     detailPage->setVisible(true);
 }
+
+void DCCNetworkModule::showAirplanePage()
+{
+    AirplaneModepage *p = new AirplaneModepage();
+    m_frameProxy->pushWidget(this, p);
+
+    connect(this, &DCCNetworkModule::popAirplaneModePage, p, [this] {
+        if (m_indexWidget) {
+            m_indexWidget->showDefaultWidget();
+        }
+    });
+}
+
+void DCCNetworkModule::onWirelessAccessPointsOrAdapterChange()
+{
+    if (m_indexWidget) {
+        bool bSupportAirplaneMode = supportAirplaneMode();
+        m_indexWidget->setModelVisible("networkAirplane", bSupportAirplaneMode);
+        if (!bSupportAirplaneMode) {
+            emit popAirplaneModePage();
+        }
+    }
+}
