@@ -78,6 +78,14 @@
         <comment>button</comment>
         <translation>Salva</translation>
     </message>
+    <message>
+        <source>Connecting</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>Disconnetti</translation>
+    </message>
     <message>
         <source>Are you sure you want to delete this configuration?</source>
         <translation>Sicuro di voler eliminare questa configurazione?</translation>
@@ -197,6 +205,12 @@
         <source>VPN</source>
         <translation>VPN</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Modalità aereo</translation>
+        <extra-child_page>Airplane Mode</extra-child_page>
+        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
+    </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>Scheda di rete</translation>
@@ -358,6 +372,17 @@
         <extra-contents_path>/network/Network Details</extra-contents_path>
     </message>
 </context>
+<context>
+    <name>dccV20::network::AirplaneModepage</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Modalità aereo</translation>
+    </message>
+    <message>
+        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
+        <translation>L&apos;abilitazione della modalità aereo disattiva la rete wireless, l&apos;hotspot personale e il Bluetooth</translation>
+    </message>
+</context>
 <context>
     <name>DNSSection</name>
     <message>
@@ -644,6 +669,11 @@
         <source>Application Proxy</source>
         <translation>Proxy applicazione</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Modalità aereo</translation>
+        <extra-contents_path>/network/Airplane</extra-contents_path>
+    </message>
     <message>
         <source>Network Details</source>
         <translation>Dettagli di rete</translation>
@@ -1922,14 +1952,14 @@
         <source>Security Type</source>
         <translation>Tipo sicurezza</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Banda</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Canale</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Banda</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>Interfaccia</translation>
