@@ -78,6 +78,14 @@
         <comment>button</comment>
         <translation>Guardar</translation>
     </message>
+    <message>
+        <source>Connecting</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>Desligar</translation>
+    </message>
     <message>
         <source>Are you sure you want to delete this configuration?</source>
         <translation>Tem a certeza que deseja eliminar esta configuração?</translation>
@@ -197,6 +205,12 @@
         <source>VPN</source>
         <translation>VPN</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Modo de avião</translation>
+        <extra-child_page>Airplane Mode</extra-child_page>
+        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
+    </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>Adaptador de rede por cabo</translation>
@@ -358,6 +372,17 @@
         <extra-contents_path>/network/Network Details</extra-contents_path>
     </message>
 </context>
+<context>
+    <name>dccV20::network::AirplaneModepage</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Modo de avião</translation>
+    </message>
+    <message>
+        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DNSSection</name>
     <message>
@@ -471,7 +496,7 @@
     <name>IPV4InputSection</name>
     <message>
         <source>Duplicate IP address</source>
-        <translation type="unfinished"/>
+        <translation>Endereço IP duplicado</translation>
     </message>
     <message>
         <source>Invalid IP address</source>
@@ -483,7 +508,7 @@
     </message>
     <message>
         <source>Only one gateway is allowed</source>
-        <translation type="unfinished"/>
+        <translation>Apenas um Gateway é permitido</translation>
     </message>
     <message>
         <source>Invalid gateway</source>
@@ -502,7 +527,7 @@
     <name>IPV6InputSection</name>
     <message>
         <source>Duplicate IP address</source>
-        <translation type="unfinished"/>
+        <translation>Endereço IP duplicado</translation>
     </message>
     <message>
         <source>Invalid IP address</source>
@@ -510,7 +535,7 @@
     </message>
     <message>
         <source>Only one gateway is allowed</source>
-        <translation type="unfinished"/>
+        <translation>Apenas um Gateway é permitido</translation>
     </message>
     <message>
         <source>Invalid gateway</source>
@@ -644,6 +669,11 @@
         <source>Application Proxy</source>
         <translation>Proxy da aplicação</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Modo de avião</translation>
+        <extra-contents_path>/network/Airplane</extra-contents_path>
+    </message>
     <message>
         <source>Network Details</source>
         <translation>Detalhes da rede</translation>
@@ -986,7 +1016,7 @@
     </message>
     <message>
         <source>WPA3 Personal</source>
-        <translation type="unfinished"/>
+        <translation>WPA3 Personal</translation>
     </message>
     <message>
         <source>Security</source>
@@ -1036,7 +1066,7 @@
     </message>
     <message>
         <source>WPA3 Personal</source>
-        <translation type="unfinished"/>
+        <translation>WPA3 Personal</translation>
     </message>
     <message>
         <source>Shared key</source>
@@ -1922,14 +1952,14 @@
         <source>Security Type</source>
         <translation>Tipo de Segurança</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Banda</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Canal</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Banda</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>Interface</translation>
