@@ -78,6 +78,14 @@
         <comment>button</comment>
         <translation>Ruaje</translation>
     </message>
+    <message>
+        <source>Connecting</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>Shkëputu</translation>
+    </message>
     <message>
         <source>Are you sure you want to delete this configuration?</source>
         <translation>Jeni i sigurt se doni të fshihet ky formësim?</translation>
@@ -197,6 +205,12 @@
         <source>VPN</source>
         <translation>VPN</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Mënyra Aeroplan</translation>
+        <extra-child_page>Airplane Mode</extra-child_page>
+        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
+    </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>Përshtatës Rrjeti Me Fill</translation>
@@ -358,6 +372,17 @@
         <extra-contents_path>/network/Network Details</extra-contents_path>
     </message>
 </context>
+<context>
+    <name>dccV20::network::AirplaneModepage</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Mënyra Aeroplan</translation>
+    </message>
+    <message>
+        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
+        <translation>Aktivizimi i mënyrës aeroplan çaktivizon rrjetin pa fill, hotspot-in personal dhe Bluetooth-in</translation>
+    </message>
+</context>
 <context>
     <name>DNSSection</name>
     <message>
@@ -377,7 +402,7 @@
     </message>
     <message>
         <source>Not Bind</source>
-        <translation type="unfinished"/>
+        <translation>Jo e lidhur</translation>
     </message>
     <message>
         <source>Device MAC Addr</source>
@@ -644,6 +669,11 @@
         <source>Application Proxy</source>
         <translation>Ndërmjetës Aplikacioni</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Mënyra Aeroplan</translation>
+        <extra-contents_path>/network/Airplane</extra-contents_path>
+    </message>
     <message>
         <source>Network Details</source>
         <translation>Hollësi Rrjeti</translation>
@@ -760,7 +790,7 @@
     </message>
     <message>
         <source>Stateful MPPE</source>
-        <translation type="unfinished"/>
+        <translation>Gjendje  MPPE</translation>
     </message>
 </context>
 <context>
@@ -943,7 +973,7 @@
     </message>
     <message>
         <source>Provisioning</source>
-        <translation type="unfinished"/>
+        <translation>Provisioni</translation>
     </message>
     <message>
         <source>PAC file</source>
@@ -1119,7 +1149,7 @@
     </message>
     <message>
         <source>Restrict Tunnel TCP MSS</source>
-        <translation type="unfinished"/>
+        <translation>Kufizo Tunalin TCP MSS</translation>
     </message>
     <message>
         <source>Randomize Remote Hosts</source>
@@ -1138,7 +1168,7 @@
     </message>
     <message>
         <source>Netscreen</source>
-        <translation type="unfinished"/>
+        <translation>Netscreen</translation>
     </message>
     <message>
         <source>Secure (default)</source>
@@ -1206,7 +1236,7 @@
     </message>
     <message>
         <source>NAT Traversal Mode</source>
-        <translation type="unfinished"/>
+        <translation>menyra e udhetimit NAT</translation>
     </message>
     <message>
         <source>IKE DH Group</source>
@@ -1214,7 +1244,7 @@
     </message>
     <message>
         <source>Forward Secrecy</source>
-        <translation type="unfinished"/>
+        <translation>Perpara sekretet</translation>
     </message>
     <message>
         <source>Local Port</source>
@@ -1245,7 +1275,7 @@
     </message>
     <message>
         <source>Pre-Shared Key</source>
-        <translation type="unfinished"/>
+        <translation>Celes i para-shperndare</translation>
     </message>
     <message>
         <source>Phase1 Algorithms</source>
@@ -1466,7 +1496,7 @@
     </message>
     <message>
         <source>Stateful MPPE</source>
-        <translation type="unfinished"/>
+        <translation>Gjendje  MPPE</translation>
     </message>
 </context>
 <context>
@@ -1679,7 +1709,7 @@
     </message>
     <message>
         <source>Pre-Shared Key</source>
-        <translation type="unfinished"/>
+        <translation>Celes i para-shperndare</translation>
     </message>
     <message>
         <source>Gateway</source>
@@ -1881,7 +1911,7 @@
     </message>
     <message>
         <source>Not Bind</source>
-        <translation type="unfinished"/>
+        <translation>Jo e lidhur</translation>
     </message>
     <message>
         <source>SSID</source>
@@ -1922,14 +1952,14 @@
         <source>Security Type</source>
         <translation>Lloj Sigurie</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Bandë</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Kanal</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Bandë</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>Ndërfaqe</translation>
