@@ -499,6 +499,17 @@ void WirelessItem::expandWidget(ExpandWidget type, bool autoDisconnect)
         m_ssidEdit->lineEdit()->setFocus();
         break;
     case ExpandWidget::ShowPassword:
+        // 如果当前需要输入密码的ap不是处理正在连接状态，则隐藏起来，目的是为了处理在控制中心快速切换ap导致连接状态错误的问题
+        const QString ssidWaitingForPassword = LocalClient::instance()->ssidWaitingForPassword();
+        if (m_accessPoint && LocalClient::instance()->waitClientType() == LocalClient::Self && ssidWaitingForPassword == m_accessPoint->ssid()) {
+            if (m_accessPoint->status() != ConnectionStatus::Activating) {
+                expandWidget(ExpandWidget::Hide);
+                break;
+            }
+            // 有时候显示密码输入框时, ap的status还没有来得变更，有可能会在几毫秒(不确定)后变更，需要绑定信号进行处理
+            connect(m_accessPoint, &AccessPoints::connectionStatusChanged, this, &WirelessItem::onApConnectionStatusChanged, Qt::UniqueConnection);
+        }
+
         m_expandItem->setVisible(true);
         m_topItem->setVisible(true);
         standardItem()->setSizeHint(QSize(-1, 130));
@@ -511,6 +522,13 @@ void WirelessItem::expandWidget(ExpandWidget type, bool autoDisconnect)
     emit sizeChanged();
 }
 
+void WirelessItem::onApConnectionStatusChanged(ConnectionStatus status)
+{
+    if (status != ConnectionStatus::Activating && expandVisible()) {
+        expandWidget(ExpandWidget::Hide);
+    }
+}
+
 void WirelessItem::createPasswordEdit()
 {
     //　密码输入窗
@@ -679,7 +697,7 @@ const QDateTime WirelessItem::timeStamp(WirelessConnection *connection) const
 
 void WirelessItem::onCancel()
 {
-    if (m_accessPoint && m_accessPoint->status() == ConnectionStatus::Activating) {
+    if (m_accessPoint && (m_accessPoint->status() == ConnectionStatus::Activating || m_accessPoint->ssid() == m_device->activeAp())) {
         m_device->disconnectNetwork();
         QList<WirelessConnection *> connections = m_device->items();
         // 断开连接后，找到最后一次连接的热点
