@@ -22,6 +22,7 @@
 #include "network_module.h"
 #include "networkpluginhelper.h"
 #include "networkdialog.h"
+#include "secretagent.h"
 #include "trayicon.h"
 #include "notificationmanager.h"
 
@@ -74,7 +75,9 @@ NetworkModule::NetworkModule(QObject *parent)
         for (dde::network::NetworkDeviceBase *device : dde::network::NetworkController::instance()->devices()) {
             onAddDevice(device->path());
         }
+        m_secretAgent = new NETWORKPLUGIN_NAMESPACE::SecretAgent(true, this);
     }
+
     m_networkDialog->runServer(true);
 }
 
@@ -101,6 +104,7 @@ QWidget *NetworkModule::itemWidget() const
     connect(m_networkDialog, &NetworkDialog::requestPosition, trayIcon, &TrayIcon::showNetworkDialog);
     // 处理内存
     connect(m_networkHelper, &NetworkPluginHelper::destroyed, trayIcon, &TrayIcon::deleteLater);
+    trayIcons.append(QPointer<TrayIcon>(trayIcon));
     return trayIcon;
 }
 
