@@ -400,7 +400,7 @@ void DeviceManagerRealize::changeWirelessStatus(Device::State newstate)
         if (m_activeWirelessConnection) {
             AccessPoints *ap = findAccessPoints(m_activeWirelessConnection->connection()->ssid());
             if (ap)
-                ap->m_status = ConnectionStatus::Deactivated;
+                ap->updateConnectionStatus(ConnectionStatus::Deactivated);
 
             m_activeWirelessConnection = nullptr;
             Q_EMIT activeConnectionChanged();
@@ -419,7 +419,7 @@ void DeviceManagerRealize::changeWirelessStatus(Device::State newstate)
     if (m_activeWirelessConnection && m_activeWirelessConnection != currentConnection) {
         AccessPoints *ap = findAccessPoints(m_activeWirelessConnection->connection()->ssid());
         if (ap)
-            ap->m_status = ConnectionStatus::Deactivated;
+            ap->updateConnectionStatus(ConnectionStatus::Deactivated);
         oldStatus = ConnectionStatus::Unknown;
     }
 
@@ -428,7 +428,7 @@ void DeviceManagerRealize::changeWirelessStatus(Device::State newstate)
         m_activeWirelessConnection = currentConnection;
         AccessPoints *ap = findAccessPoints(currentConnection->connection()->ssid());
         if (ap) {
-            ap->m_status = newStatus;
+            ap->updateConnectionStatus(newStatus);
             Q_EMIT activeConnectionChanged();
         }
     }
